"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replace = exports.getSelection = exports.replaceAll = void 0;
const tslib_1 = require("tslib");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const monaco = tslib_1.__importStar(require("@opensumi/ide-monaco"));
async function replaceAll(documentModelManager, workspaceEditService, resultMap, replaceText, searchText, isUseRegexp, dialogService, messageService, insertResultTotal) {
    if (resultMap.size < 1) {
        return false;
    }
    const resultTotal = Object.assign({}, insertResultTotal);
    if (dialogService && resultTotal) {
        const buttons = {
            [(0, ide_core_browser_1.localize)('search.replace.buttonCancel')]: false,
            [(0, ide_core_browser_1.localize)('search.replace.buttonOK')]: true,
        };
        const selection = await dialogService.open((0, ide_core_common_1.formatLocalize)('search.removeAll.occurrences.files.confirmation.message', String(resultTotal.resultNum), String(resultTotal.fileNum), replaceText), ide_core_common_1.MessageType.Warning, Object.keys(buttons));
        if (!buttons[selection]) {
            return buttons[selection];
        }
    }
    for (const resultArray of resultMap) {
        const results = resultArray[1];
        await replace(documentModelManager, workspaceEditService, results, replaceText, searchText, isUseRegexp);
    }
    if (messageService && resultTotal) {
        messageService.info((0, ide_core_common_1.formatLocalize)('search.replaceAll.occurrencesMessage', String(resultTotal.resultNum), String(resultTotal.fileNum), replaceText));
    }
    return true;
}
exports.replaceAll = replaceAll;
function getSelection(result) {
    const selection = new monaco.Selection(result.line, result.matchStart, result.line, result.matchStart + result.matchLength);
    return [selection];
}
exports.getSelection = getSelection;
async function replace(documentModelManager, workspaceEditService, results, replaceText, searchText, isUseRegexp) {
    var _a;
    const autoSavedDocs = results
        .map((result) => documentModelManager.getModelReference(new ide_core_common_1.URI(result.fileUri)))
        .filter((doc) => (doc === null || doc === void 0 ? void 0 : doc.instance) && !doc.instance.dirty);
    const edits = [];
    for (const result of results) {
        let replaceResult = replaceText;
        if (isUseRegexp && replaceText) {
            let regexp;
            try {
                regexp = new RegExp(searchText);
            }
            catch (e) {
                continue;
            }
            const matchLineText = (_a = result.renderLineText) === null || _a === void 0 ? void 0 : _a.slice(result.matchStart - 1, result.matchStart + result.matchLength - 1);
            if (matchLineText) {
                replaceResult = matchLineText.replace(regexp, replaceText);
            }
        }
        edits.push({
            options: {
                dirtyIfInEditor: true,
            },
            resource: new ide_core_common_1.URI(result.fileUri),
            textEdit: {
                range: new monaco.Range(result.line, result.matchStart, result.line, result.matchStart + result.matchLength),
                text: replaceResult,
            },
        });
    }
    await workspaceEditService.apply({
        edits,
    });
    autoSavedDocs.forEach((doc) => {
        doc.instance.save();
    });
}
exports.replace = replace;
//# sourceMappingURL=replace.js.map