"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchHistory = exports.SEARCH_WORD_SCOPE = void 0;
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
exports.SEARCH_WORD_SCOPE = 'SEARCH_WORD';
class SearchHistory {
    constructor(searchServiceClient, recentStorage) {
        this.searchHistoryList = [];
        this.currentIndex = -1;
        this.searchServiceClient = searchServiceClient;
        this.recentStorage = recentStorage;
    }
    setRecentSearchWord() {
        if (this.currentIndex === -1) {
            this.currentIndex = this.searchHistoryList.length;
        }
        this.currentIndex = this.currentIndex - 1;
        let value = this.searchHistoryList[this.currentIndex];
        if (this.currentIndex < 0) {
            this.currentIndex = 0;
            value = this.searchHistoryList[this.currentIndex];
            return this.setSearchValue(value);
        }
        if (!value) {
            return;
        }
        if (this.searchServiceClient.searchValue === value) {
            return this.setRecentSearchWord();
        }
        this.setSearchValue(value);
    }
    setBackRecentSearchWord() {
        this.currentIndex = this.currentIndex + 1;
        let value = this.searchHistoryList[this.currentIndex];
        if (this.currentIndex >= this.searchHistoryList.length) {
            this.currentIndex = this.searchHistoryList.length - 1;
            value = this.searchHistoryList[this.currentIndex];
            return this.setSearchValue(value);
        }
        if (!value) {
            return;
        }
        if (this.searchServiceClient.searchValue === value) {
            return this.setBackRecentSearchWord();
        }
        this.setSearchValue(value);
    }
    async initSearchHistory() {
        if (this.searchHistoryList.length > 0) {
            return;
        }
        const list = await this.getMostRecentlySearchWord();
        this.searchHistoryList = this.searchHistoryList.concat(list || []);
    }
    async setSearchHistory(word) {
        if (this.searchHistoryList.some((value) => value === word)) {
            return;
        }
        this.searchHistoryList.push(word);
        await this.setMostRecentlySearchWord(word);
    }
    async getMostRecentlySearchWord() {
        const recentStorage = await this.recentStorage.getScopeStorage();
        const list = (await recentStorage.get(exports.SEARCH_WORD_SCOPE)) || [];
        return list;
    }
    async setMostRecentlySearchWord(word) {
        const recentStorage = await this.recentStorage.getScopeStorage();
        let list = [];
        const oldList = (await this.getMostRecentlySearchWord()) || [];
        if ((0, ide_core_browser_1.isArray)(word)) {
            list = list.concat(word);
        }
        else {
            list.push(word);
        }
        list = oldList.concat(list);
        list = Array.from(new Set(list));
        // 仅存储10个
        list = list.slice(list.length - 10, list.length);
        recentStorage.set(exports.SEARCH_WORD_SCOPE, list);
    }
    setSearchValue(value) {
        this.searchServiceClient.searchValue = value;
        this.searchServiceClient.searchDebounce();
    }
    reset() {
        this.currentIndex = -1;
    }
}
exports.SearchHistory = SearchHistory;
//# sourceMappingURL=search-history.js.map