"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchContribution = void 0;
const tslib_1 = require("tslib");
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const container_id_1 = require("@opensumi/ide-core-browser/lib/common/container-id");
const search_1 = require("@opensumi/ide-core-browser/lib/contextkey/search");
const layout_1 = require("@opensumi/ide-core-browser/lib/layout");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const di_helper_1 = require("@opensumi/ide-core-common/lib/di-helper");
const index_1 = require("@opensumi/ide-editor/lib/browser/index");
const ide_main_layout_1 = require("@opensumi/ide-main-layout");
const common_1 = require("@opensumi/ide-main-layout/lib/common");
const ide_overlay_1 = require("@opensumi/ide-overlay");
const ide_workspace_edit_1 = require("@opensumi/ide-workspace-edit");
const common_2 = require("../common");
const replace_1 = require("./replace");
const search_preferences_1 = require("./search-preferences");
const search_view_1 = require("./search.view");
const search_tree_service_1 = require("./tree/search-tree.service");
const tree_model_service_1 = require("./tree/tree-model.service");
const tree_node_defined_1 = require("./tree/tree-node.defined");
let SearchContribution = class SearchContribution {
    constructor() {
        this.schema = search_preferences_1.searchPreferenceSchema;
        this.toDispose = new ide_core_common_1.DisposableCollection();
    }
    registerCommands(commands) {
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.OPEN_SEARCH, {
            execute: (options) => {
                const bar = this.mainLayoutService.getTabbarHandler(container_id_1.SEARCH_CONTAINER_ID);
                if (!bar) {
                    return;
                }
                bar.activate();
                if (options && options.includeValue) {
                    this.searchBrowserService.includeValue = options.includeValue;
                    this.searchBrowserService.updateUIState({ isDetailOpen: true });
                    this.searchBrowserService.search();
                    return;
                }
                this.searchBrowserService.searchEditorSelection();
                this.searchBrowserService.focus();
                this.searchBrowserService.search();
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.REFRESH, {
            execute: () => {
                this.searchBrowserService.search();
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.CLEAN, {
            execute: () => {
                this.searchBrowserService.clean();
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.GET_RECENT_SEARCH_WORD, {
            execute: (e) => {
                this.searchBrowserService.setRecentSearchWord();
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.GET_BACK_RECENT_SEARCH_WORD, {
            execute: () => {
                this.searchBrowserService.setBackRecentSearchWord();
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.MENU_REPLACE, {
            execute: async (node) => {
                if (!tree_node_defined_1.SearchFileNode.is(node)) {
                    const resultMap = new Map();
                    resultMap.set(node.resource.toString(), [node.contentResult]);
                    await (0, replace_1.replaceAll)(this.documentModelManager, this.workspaceEditService, resultMap, this.searchBrowserService.replaceValue, this.searchBrowserService.searchValue, this.searchBrowserService.UIState.isUseRegexp);
                }
            },
            isVisible: () => !tree_node_defined_1.SearchFileNode.is(this.searchModelService.contextMenuNode),
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.MENU_REPLACE_ALL, {
            execute: async (node) => {
                if (!tree_node_defined_1.SearchFileNode.is(node)) {
                    return;
                }
                const resultMap = new Map();
                if (!node.children) {
                    return;
                }
                const contentSearchResult = node.children.map((child) => child.contentResult);
                const buttons = {
                    [(0, ide_core_browser_1.localize)('search.replace.buttonCancel')]: false,
                    [(0, ide_core_browser_1.localize)('search.replace.buttonOK')]: true,
                };
                const selection = await this.dialogService.open((0, ide_core_common_1.formatLocalize)('search.removeAll.occurrences.file.confirmation.message', String(contentSearchResult.length)), ide_core_common_1.MessageType.Warning, Object.keys(buttons));
                if (selection && !buttons[selection]) {
                    return buttons[selection];
                }
                resultMap.set(node.resource.toString(), contentSearchResult);
                await (0, replace_1.replaceAll)(this.documentModelManager, this.workspaceEditService, resultMap, this.searchBrowserService.replaceValue, this.searchBrowserService.searchValue, this.searchBrowserService.UIState.isUseRegexp);
            },
            isVisible: () => !tree_node_defined_1.SearchFileNode.is(this.searchModelService.contextMenuNode),
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.MENU_HIDE, {
            execute: (node) => {
                var _a, _b;
                if (tree_node_defined_1.SearchFileNode.is(node)) {
                    this.searchBrowserService.resultTotal.fileNum -= 1;
                    this.searchBrowserService.resultTotal.resultNum -= node.branchSize;
                    this.searchModelService.treeModel.root.unlinkItem(node);
                }
                else {
                    this.searchBrowserService.resultTotal.resultNum -= 1;
                    if (((_b = (_a = node.parent) === null || _a === void 0 ? void 0 : _a.children) === null || _b === void 0 ? void 0 : _b.length) === 1) {
                        this.searchBrowserService.resultTotal.fileNum -= 1;
                        this.searchModelService.treeModel.root.unlinkItem(node.parent);
                    }
                    node.parent.unlinkItem(node);
                }
                this.searchBrowserService.fireTitleChange();
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.MENU_COPY, {
            execute: (node) => {
                var _a;
                if (!tree_node_defined_1.SearchFileNode.is(node)) {
                    const result = node.contentResult;
                    this.clipboardService.writeText(`${result.line},${result.matchStart}:  ${result.renderLineText}`);
                }
                else {
                    const uri = node.resource;
                    let text = `${uri.codeUri.fsPath.toString()}\n`;
                    (_a = node.children) === null || _a === void 0 ? void 0 : _a.forEach((node) => {
                        const result = node.contentResult;
                        text = text + `${result.line},${result.matchStart}: ${result.renderLineText} \n`;
                    });
                    this.clipboardService.writeText(text);
                }
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.MENU_COPY_ALL, {
            execute: (node) => {
                var _a;
                let nodes;
                if (!node) {
                    nodes = this.searchModelService.treeModel.root.children;
                }
                else {
                    if (tree_node_defined_1.SearchFileNode.is(node)) {
                        nodes = [node];
                    }
                    else {
                        nodes = [node.parent];
                    }
                }
                if (!nodes) {
                    return;
                }
                let copyText = '';
                for (let i = 0, len = nodes.length; i < len; i++) {
                    const uri = nodes[i].resource;
                    let text = `${uri.codeUri.fsPath.toString()}\n`;
                    (_a = nodes[i].children) === null || _a === void 0 ? void 0 : _a.forEach((node) => {
                        const result = node.contentResult;
                        text = text + `${result.line},${result.matchStart}: ${result.renderLineText} \n`;
                    });
                    copyText += text;
                    if (i < len) {
                        copyText += '\n';
                    }
                }
                this.clipboardService.writeText(copyText);
            },
        });
        commands.registerCommand(ide_core_browser_1.SEARCH_COMMANDS.MENU_COPY_PATH, {
            execute: (node) => {
                this.clipboardService.writeText(node.resource.codeUri.fsPath.toString());
            },
        });
    }
    registerMenus(menuRegistry) {
        menuRegistry.registerMenuItem(next_1.MenuId.SearchContext, {
            command: ide_core_browser_1.SEARCH_COMMANDS.MENU_REPLACE.id,
            order: 1,
            group: '0_operator',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.SearchContext, {
            command: ide_core_browser_1.SEARCH_COMMANDS.MENU_REPLACE_ALL.id,
            order: 2,
            group: '0_operator',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.SearchContext, {
            command: ide_core_browser_1.SEARCH_COMMANDS.MENU_HIDE.id,
            order: 3,
            group: '0_operator',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.SearchContext, {
            command: ide_core_browser_1.SEARCH_COMMANDS.MENU_COPY.id,
            order: 1,
            group: '1_copy',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.SearchContext, {
            command: ide_core_browser_1.SEARCH_COMMANDS.MENU_COPY_PATH.id,
            order: 2,
            group: '1_copy',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.SearchContext, {
            command: ide_core_browser_1.SEARCH_COMMANDS.MENU_COPY_ALL.id,
            order: 3,
            group: '1_copy',
        });
    }
    registerKeybindings(keybindings) {
        keybindings.registerKeybinding({
            command: ide_core_browser_1.SEARCH_COMMANDS.OPEN_SEARCH.id,
            keybinding: 'ctrlcmd+shift+f',
        });
        keybindings.registerKeybinding({
            command: ide_core_browser_1.SEARCH_COMMANDS.GET_BACK_RECENT_SEARCH_WORD.id,
            keybinding: 'down',
            when: search_1.SearchInputBoxFocusedKey.raw,
        });
        keybindings.registerKeybinding({
            command: ide_core_browser_1.SEARCH_COMMANDS.GET_RECENT_SEARCH_WORD.id,
            keybinding: 'up',
            when: search_1.SearchInputBoxFocusedKey.raw,
        });
    }
    registerComponent(registry) {
        registry.register('@opensumi/ide-search', [], {
            containerId: container_id_1.SEARCH_CONTAINER_ID,
            iconClass: (0, ide_core_browser_1.getIcon)('search'),
            title: (0, ide_core_browser_1.localize)('search.title'),
            component: search_view_1.Search,
            priority: 9,
            activateKeyBinding: 'ctrlcmd+shift+f',
        });
    }
    registerToolbarItems(registry) {
        registry.registerItem({
            id: ide_core_browser_1.SEARCH_COMMANDS.CLEAN.id,
            command: ide_core_browser_1.SEARCH_COMMANDS.CLEAN.id,
            viewId: container_id_1.SEARCH_CONTAINER_ID,
            tooltip: (0, ide_core_browser_1.localize)('search.ClearSearchResultsAction.label'),
            enabledWhen: 'canClearSearchResult',
        });
        registry.registerItem({
            id: ide_core_browser_1.SEARCH_COMMANDS.REFRESH.id,
            command: ide_core_browser_1.SEARCH_COMMANDS.REFRESH.id,
            viewId: container_id_1.SEARCH_CONTAINER_ID,
            tooltip: (0, ide_core_browser_1.localize)('search.RefreshAction.label'),
            enabledWhen: 'canRefreshSearchResult',
        });
    }
    onDidRender() {
        const handler = this.mainLayoutService.getTabbarHandler(container_id_1.SEARCH_CONTAINER_ID);
        if (handler) {
            this.searchTreeService.viewReady.then(() => {
                const activated = handler.isActivated();
                if (activated) {
                    this.searchModelService.activate();
                }
            });
            handler.onActivate(() => {
                this.searchBrowserService.initSearchHistory();
                this.searchBrowserService.focus();
                this.searchModelService.activate();
            });
            handler.onInActivate(() => {
                this.searchTreeService.removeHighlightRange();
                this.searchBrowserService.blur();
                this.searchModelService.deactivate();
            });
        }
    }
    dispose() {
        this.toDispose.dispose();
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.IMainLayoutService),
    tslib_1.__metadata("design:type", Object)
], SearchContribution.prototype, "mainLayoutService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_2.IContentSearchClientService),
    tslib_1.__metadata("design:type", Object)
], SearchContribution.prototype, "searchBrowserService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(search_tree_service_1.SearchTreeService),
    tslib_1.__metadata("design:type", search_tree_service_1.SearchTreeService)
], SearchContribution.prototype, "searchTreeService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(index_1.IEditorDocumentModelService),
    tslib_1.__metadata("design:type", Object)
], SearchContribution.prototype, "documentModelManager", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_workspace_edit_1.IWorkspaceEditService),
    tslib_1.__metadata("design:type", Object)
], SearchContribution.prototype, "workspaceEditService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_overlay_1.IDialogService),
    tslib_1.__metadata("design:type", Object)
], SearchContribution.prototype, "dialogService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(tree_model_service_1.SearchModelService),
    tslib_1.__metadata("design:type", tree_model_service_1.SearchModelService)
], SearchContribution.prototype, "searchModelService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IClipboardService),
    tslib_1.__metadata("design:type", Object)
], SearchContribution.prototype, "clipboardService", void 0);
SearchContribution = tslib_1.__decorate([
    (0, di_helper_1.Domain)(ide_core_browser_1.ClientAppContribution, ide_core_common_1.CommandContribution, ide_core_browser_1.KeybindingContribution, ide_core_browser_1.ComponentContribution, layout_1.TabBarToolbarContribution, ide_core_browser_1.PreferenceContribution, ide_main_layout_1.MainLayoutContribution, next_1.MenuContribution)
], SearchContribution);
exports.SearchContribution = SearchContribution;
//# sourceMappingURL=search.contribution.js.map