"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SearchRulesWidget = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importDefault(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const config_provider_1 = require("@opensumi/ide-core-browser/lib/react-providers/config-provider");
const icon_1 = require("@opensumi/ide-core-browser/lib/style/icon/icon");
const localize_1 = require("@opensumi/ide-core-common/lib/localize");
const content_search_1 = require("../common/content-search");
const search_module_less_1 = tslib_1.__importDefault(require("./search.module.less"));
const IncludeRuleContent = () => (react_1.default.createElement("div", { className: (0, classnames_1.default)(search_module_less_1.default.include_rule_content) },
    react_1.default.createElement("ul", null,
        react_1.default.createElement("li", null,
            ", : ",
            (0, localize_1.localize)('search.help.concatRule')),
        react_1.default.createElement("li", null,
            "* : ",
            (0, localize_1.localize)('search.help.matchOneOrMoreRule')),
        react_1.default.createElement("li", null,
            "? : ",
            (0, localize_1.localize)('search.help.matchOne')),
        react_1.default.createElement("li", null,
            "** : ",
            (0, localize_1.localize)('search.help.matchAny')),
        react_1.default.createElement("li", null,
            " : ",
            (0, localize_1.localize)('search.help.matchWithGroup')),
        react_1.default.createElement("li", null,
            "[] : ",
            (0, localize_1.localize)('search.help.matchRange')))));
const ExcludeRuleContent = react_1.default.memo(() => {
    const configContext = react_1.default.useContext(config_provider_1.ConfigContext);
    const { injector } = configContext;
    const searchBrowserService = injector.get(content_search_1.IContentSearchClientService);
    const excludeList = react_1.default.useMemo(() => searchBrowserService.getPreferenceSearchExcludes(), [searchBrowserService]);
    return (react_1.default.createElement("div", { className: (0, classnames_1.default)(search_module_less_1.default.exclude_rule_content) },
        react_1.default.createElement("div", null, excludeList.map((exclude, index) => {
            if (index === excludeList.length - 1) {
                return exclude;
            }
            return `${exclude}, `;
        }))));
});
const IncludeInput = react_1.default.memo(({ includeValue, isOnlyOpenEditors, onSearch, onChangeInclude, onOnlyOpenEditorsToggle, }) => (react_1.default.createElement("div", { className: (0, classnames_1.default)(search_module_less_1.default.glob_field) },
    react_1.default.createElement("div", { className: (0, classnames_1.default)(search_module_less_1.default.label) },
        react_1.default.createElement("span", { className: search_module_less_1.default.limit }, (0, localize_1.localize)('search.includes')),
        react_1.default.createElement("span", { className: (0, classnames_1.default)(search_module_less_1.default.include_rule) },
            react_1.default.createElement(ide_components_1.Popover, { id: 'show_include_rule', title: (0, localize_1.localize)('search.help.supportRule'), content: react_1.default.createElement(IncludeRuleContent, null), trigger: ide_components_1.PopoverTriggerType.hover, delay: 0.5, position: ide_components_1.PopoverPosition.right },
                react_1.default.createElement("a", null, (0, localize_1.localize)('search.help.showIncludeRule'))))),
    react_1.default.createElement(ide_components_1.Input, { value: includeValue, type: 'text', placeholder: (0, localize_1.localize)('search.includes.description'), onKeyUp: onSearch, onChange: onChangeInclude, id: 'include-input-field', addonAfter: [
            react_1.default.createElement("span", { key: 'onlyOpenEditors', className: (0, classnames_1.default)((0, icon_1.getExternalIcon)('book'), search_module_less_1.default.search_option, { [search_module_less_1.default.select]: isOnlyOpenEditors }), title: (0, localize_1.localize)('search.onlyOpenEditors'), onClick: onOnlyOpenEditorsToggle }),
        ] }))), (prevProps, nextProps) => prevProps.includeValue === nextProps.includeValue && prevProps.isOnlyOpenEditors === nextProps.isOnlyOpenEditors);
const ExcludeInput = react_1.default.memo(({ isIncludeIgnored, excludeValue, onIncludeIgnoredToggle, onChangeExclude, onOpenPreference, onSearch, }) => (react_1.default.createElement("div", { className: (0, classnames_1.default)(search_module_less_1.default.glob_field, search_module_less_1.default.search_excludes) },
    react_1.default.createElement("div", { className: search_module_less_1.default.label },
        react_1.default.createElement("span", { className: search_module_less_1.default.limit }, (0, localize_1.localize)('search.excludes')),
        react_1.default.createElement("div", { className: search_module_less_1.default.use_default_excludes_wrapper },
            react_1.default.createElement(ide_components_1.CheckBox, { className: (0, classnames_1.default)(search_module_less_1.default.checkbox), label: (0, localize_1.localize)('search.excludes.default.enable'), checked: !isIncludeIgnored, id: 'search-input-isIncludeIgnored', onChange: onIncludeIgnoredToggle }),
            react_1.default.createElement(ide_components_1.Popover, { title: (0, localize_1.localize)('search.help.excludeList'), overlayClassName: (0, classnames_1.default)(search_module_less_1.default.search_excludes_description), id: 'search_excludes', action: (0, localize_1.localize)('search.help.modify'), onClickAction: onOpenPreference, content: react_1.default.createElement(ExcludeRuleContent, null), trigger: ide_components_1.PopoverTriggerType.hover, delay: 0.5, position: ide_components_1.PopoverPosition.right },
                react_1.default.createElement("span", { className: (0, classnames_1.default)((0, icon_1.getIcon)('question-circle'), search_module_less_1.default.search_option), style: { opacity: '0.7', cursor: 'pointer' } })))),
    react_1.default.createElement(ide_components_1.Input, { type: 'text', value: excludeValue, placeholder: (0, localize_1.localize)('search.includes.description'), onKeyUp: onSearch, onChange: onChangeExclude, id: 'exclude-input-field' }))), (prevProps, nextProps) => prevProps.excludeValue === nextProps.excludeValue && prevProps.isIncludeIgnored === nextProps.isIncludeIgnored);
function isSearchRulesPropsEqual(prevProps, nextProps) {
    return (prevProps.includeValue === nextProps.includeValue &&
        prevProps.excludeValue === nextProps.excludeValue &&
        prevProps.isOnlyOpenEditors === nextProps.isOnlyOpenEditors &&
        prevProps.isIncludeIgnored === nextProps.isIncludeIgnored);
}
exports.SearchRulesWidget = react_1.default.memo(({ includeValue, excludeValue, onChangeExclude, onChangeInclude, isOnlyOpenEditors, onOnlyOpenEditorsToggle, isIncludeIgnored, onIncludeIgnoredToggle, onSearch, onOpenPreference, }) => (react_1.default.createElement("div", { className: 'glob_field-container' },
    react_1.default.createElement(IncludeInput, { includeValue: includeValue, onSearch: onSearch, onChangeInclude: onChangeInclude, isOnlyOpenEditors: isOnlyOpenEditors, onOnlyOpenEditorsToggle: onOnlyOpenEditorsToggle }),
    react_1.default.createElement(ExcludeInput, { isIncludeIgnored: isIncludeIgnored, excludeValue: excludeValue, onIncludeIgnoredToggle: onIncludeIgnoredToggle, onChangeExclude: onChangeExclude, onOpenPreference: onOpenPreference, onSearch: onSearch }))), isSearchRulesPropsEqual);
//# sourceMappingURL=search.rules.widget.js.map